Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
func New(sessionServer SessionServer, signer Signer) *verifier
Types ¶
type Session ¶
type Session interface {
// A request for username/password
ChallengeLogin() *pb.UserAction
// A request for the user to acknowledge the credentials being minted
ChallengeReview(*pb.VerifiedUser) *pb.UserAction
// The final screen showing something nice to the user prompting to close
// the window. Sets the attached cookie if set.
ChallengeComplete(*pb.BrowserCookie) *pb.UserAction
Destroy()
}
type SessionServer ¶
type Signer ¶
type Signer interface {
Sign(*pb.UserCredentialRequest, *pb.VerifiedUser) (*pb.CredentialResponse, error)
}
Click to show internal directories.
Click to hide internal directories.